pytest-tipsi-django
===================

.. contents:: **Table of Contents**
    :backlinks: none

Installation
------------

.. code-block:: bash

    $ pip install pytest-tipsi-django

License
-------

pytest-tipsi-django is distributed under the terms of the
`MIT License <https://choosealicense.com/licenses/mit>`_.
